@@ -116,6 +116,10 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
             pyproject, "test-cmd", ["cmake", "--build", "BUILD_DIR", "-t", "test"]
         )
         CHECK_RELOCATABLE = deprecate_build_system(pyproject, "check-relocatable", True)
+        if deprecate_build_system(pyproject, "any", False):
+            TAG = "py3-none-any"
+        if deprecate_build_system(pyproject, "pyver-any", False):
+            TAG = f"py3{sys.version_info.minor}-none-any"
     DISTRIBUTION = CONF["name"].replace("-", "_")
 
     LOG.info("build wheel")
@@ -281,6 +285,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
                     f"Generator: cmeel {__version__}",
                     "Root-Is-Purelib: false",
                     f"Tag: {TAG}",
+                    "",
                 ]
             )
         )
@@ -341,7 +346,7 @@ def build_wheel(wheel_directory, config_settings=None, metadata_directory=None):
             str(PREFIX),
         ]
     ).decode()
-    LOG.debug("wheel pack output: {pack}")
+    LOG.debug(f"wheel pack output: {pack}")
     name = Path(re.search("Repacking wheel as (.*\\.whl)\\.\\.\\.", pack).group(1)).name
     LOG.debug(f"returning '{name}'")
 
